# Copyright 2019-2025 Gentoo Authors
# Distributed under the terms of the GNU General Public License v2

EAPI=8

DESCRIPTION="A modern widget system"
HOMEPAGE="https://github.com/linkfrg/ignis"

if [[ ${PV} == "9999" ]]; then
	inherit git-r3
	EGIT_REPO_URI="https://github.com/linkfrg/ignis"
else
	SRC_URI="https://github.com/linkfrg/${PN}/releases/download/v${PV}/${PN}-v${PV}.tar.gz -> ${P}.tar.gz"
	KEYWORDS="~amd64 ~x86"
fi

PYTHON_COMPAT=( python3_{12..13} )

inherit meson python-single-r1

LICENSE="GPL-3"
SLOT="0"
IUSE="pipewire gstreamer networkmanager upower bluetooth"
REQUIRED_USE="${PYTHON_REQUIRED_USE}"

COMMON_DEPEND="
	${PYTHON_DEPS}
"

DEPEND="${COMMON_DEPEND}
	dev-libs/glib:2
	sys-libs/glibc
	gui-libs/gtk:4
	gui-libs/gtk4-layer-shell
	media-libs/libpulse
	dev-python/pycairo
	dev-python/pygobject
	dev-python/click
	dev-python/requests
	dev-python/loguru
	pipewire? ( media-video/pipewire[gstreamer?] )
	gstreamer? (
		media-libs/gst-plugins-good
		media-libs/gst-plugins-ugly
	)
	networkmanager? ( net-misc/networkmanager )
	upower? ( sys-power/upower )
	bluetooth? ( net-wireless/gnome-bluetooth )
	dev-lang/grass
"

BDEPEND="${COMMON_DEPEND}
	sys-devel/gettext
"

PATCHES=(
	"${FILESDIR}"/${PN}-grass-sass.patch
)

S="${WORKDIR}/${PN}"

src_configure() {
	meson_src_configure --libdir="$(get_libdir)/ignis"
}

src_install() {
	meson_src_install
	python_optimize "${D}$(python_get_sitedir)/${PN}"
}
